==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MDI_debug_interface.h <==
/* $Date: 1997/08/15 11:13:11 $  $Author: olli $  $Revision: 1.16 $ */

/**************************************************************************/ 
/* FILE:             MDI_debug_interface.h                                */
/* Autor:            Oliver Kluge                                         */
/* Erstellt:         19/12/91                                             */ 
/* Letzte Aenderung: 06/09/93                                             */  
/**************************************************************************/

#ifndef __MDI_debug_interface__ 
#define __MDI_debug_interface__


#include <signal.h>

#ifdef MACINTOSH
#include "MAC_interface.h"
#endif

#define CLEAR_ALL       'a'
#define CLEAR           'C'
#define CONT            'c'
#define NEXT            'n'
#define STEP            's'
#define WHERE           'w'
#define UP              'u'
#define DOWN            'd'
#define	STACK_PTR	'P'
#define SET_LEVEL	'L'
#define DISPLAY         'D'
#define UNDISPLAY       'U'
#define LIST            'l'
#define STOP_AT         'S'
#define STOP_IN         'i'
#define QUIT            'q'
#define PRINT           'p'
#define GOTO_PROC       'g'
#define EXECUTE         'e'
#define ACTIVATE        'x'
#define DEACTIVATE      'y'
#define TTY_HELP	'?'
#define FINISH          'f'

#define MDX_PROMPT	"mdx>"

#define CMD_DEL ' ' /* Begrenzer zwischen Befehl und 1.tem Argument */
#define ARG_DEL ';' /* Begrenzer zwischen Argumenten                */
                    /* Bsp.: print sin( x ) ; x                     */
                    /*       Befehl: print 1.Arg: sin( x ) 2.Arg: x */

#if !(defined MACINTOSH || defined MSDOS|| defined __EMX__)
#define MDI_SIG		SIGCONT
#else
#define MDI_SIG		SIGTERM
#endif

#if ( defined __linux__ )
#   define TIME_OUT         50L    /* Time out nach 500 ms */
#else
#   define TIME_OUT         500L   /* Time out nach 500 ms */
#endif

#define BUF_SIZE         512
#define FILENAME_SIZE    128    /* Max. Laenge eines Dateinamens*/

#define MDI_FRONTEND	"frontend"
#define MDI_MuPAD	"MuPAD kernel"

#define IN_OUT_FORMAT	"%c %s %ld %s\n"

#define REDISPLAY	"#"

/* MDI_write(MCLT_iostream &file, char cmd, char* filename, long line, char* procname) */

#ifdef MACINTOSH
#define MDI_write(file, cmd, filename, line, procname) \
	 MAC_send_debug_info( cmd, filename, line, procname)
#else
#ifdef OLDCOMMUNICATION
#define MDI_write(file, cmd, filename, line, procname) \
	fprintf(file, IN_OUT_FORMAT, cmd, filename, line, procname)
#else
#define MDI_write(file, cmd, filename, line, procname) \
        { sprintf(dbx_input, IN_OUT_FORMAT, cmd, filename, line, procname); \
	  if (XMUPAD) { MPR_putmessage(Send_to_xmupad, MPRCmdxcommand, dbx_input); } }
#endif
#endif

/* MDI_read(MCLT_iostream &file, char cmd, char* filename, long line, char* procname) */

#ifdef OLDCOMMUNICATION
#define MDI_read(file, cmd, filename, line, procname) \
	fscanf(file, IN_OUT_FORMAT, &cmd, &filename[0], &line, &procname[0])
#else
#define MDI_read(string, cmd, filename, line, procname) \
	sscanf(string, IN_OUT_FORMAT, &cmd, &filename[0], &line, &procname[0])
#endif

#endif /* __MDI_debug_interface__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MDI_debug_interface.h <==
/* $Date: 1999/06/02 07:21:05 $  $Author: kg $  $Revision: 1.8 $ */

/**************************************************************************/
/* FILE:             MDI_debug_interface.h                                */
/* Autor:            Oliver Kluge                                         */
/* Erstellt:         19/12/91                                             */
/* Letzte Aenderung: 06/09/93                                             */
/**************************************************************************/

#ifndef __MDI_debug_interface__
#define __MDI_debug_interface__


#include <signal.h>

#ifdef MACINTOSH
#include "MAC_interface.h"
#endif

#define CMD_DEL ' ' /* Begrenzer zwischen Befehl und 1.tem Argument */
#define ARG_DEL ';' /* Begrenzer zwischen Argumenten                */
                    /* Bsp.: print sin( x ) ; x                     */
                    /*       Befehl: print 1.Arg: sin( x ) 2.Arg: x */

#if !(defined MACINTOSH || defined MSDOS|| defined __EMX__)
#define MDI_SIG		SIGCONT
#else
#define MDI_SIG		SIGTERM
#endif

#if ( defined __linux__ )
#   define TIME_OUT         50    /* Time out nach 500 ms */
#else
#   define TIME_OUT         500   /* Time out nach 500 ms */
#endif

#define BUF_SIZE         512
#define FILENAME_SIZE    128    /* Max. Laenge eines Dateinamens*/

#define MDI_FRONTEND	"frontend"
#define MDI_MuPAD	"MuPAD kernel"

#define IN_OUT_FORMAT	"%c %s %ld %s\n"

#define REDISPLAY	"#"

/* MDI_write(MCLT_iostream &file, char cmd, char* filename, long line, char* procname) */

#ifdef MACINTOSH
#define MDI_write(file, cmd, filename, line, procname) \
	 MAC_send_debug_info( cmd, filename, line, procname)
#else
#ifdef OLDCOMMUNICATION
#define MDI_write(file, cmd, filename, line, procname) \
	fprintf(file, IN_OUT_FORMAT, cmd, filename, line, procname)
#else
#define MDI_write(file, cmd, filename, line, procname) \
        { sprintf(dbx_input, IN_OUT_FORMAT, cmd, filename, line, procname); \
	  if (XMUPAD) { MPR_putmessage(Send_to_xmupad, MPRCmdxcommand, dbx_input); } }
#endif
#endif

/* MDI_read(MCLT_iostream &file, char cmd, char* filename, long line, char* procname) */

#ifdef OLDCOMMUNICATION
#define MDI_read(file, cmd, filename, line, procname) \
	fscanf(file, IN_OUT_FORMAT, &cmd, &filename[0], &line, &procname[0])
#else
#define MDI_read(string, cmd, filename, line, procname) \
	sscanf(string, IN_OUT_FORMAT, &cmd, &filename[0], &line, &procname[0])
#endif

#endif /* __MDI_debug_interface__ */
